@@ -1,6 +1,8 @@
 import os
 
 from datahub.emitter.rest_emitter import DatahubRestEmitter
+from datahub.ingestion.graph.client import DatahubClientConfig, DataHubGraph
+from typing import Optional
 
 
 class RestClient(DatahubRestEmitter):
@@ -10,6 +12,7 @@ class RestClient(DatahubRestEmitter):
         datahub_actor: str = "urn:li:corpuser:admin",
         dataset_platform: str = "bigquery",
         dashboard_platform: str = "bigquery",
+        init_graph: bool = True,
         *args,
         **kwargs,
     ):
@@ -32,7 +35,14 @@ class RestClient(DatahubRestEmitter):
             >>> client = RestClient(gms_server=gms_server, token=token)
 
         """
-        from .entities import tags, users, datasets, glossary_terms, dashboards
+        from .entities import (
+            tags,
+            users,
+            datasets,
+            glossary_terms,
+            dashboards,
+            data_jobs,
+        )
 
         self.graphql_url = os.getenv("DATAHUB_GRAPHQL_HOST") or kwargs.pop(
             "graphql_server", None
@@ -54,6 +64,15 @@ class RestClient(DatahubRestEmitter):
             if self.graphql_url
             else f"{self.datahub_gms_server}/api/graphql"
         )
+        self.graph: Optional[DataHubGraph] = (
+            DataHubGraph(
+                DatahubClientConfig(
+                    server=self.datahub_gms_server, token=self.datahub_token
+                )
+            )
+            if init_graph
+            else None
+        )
         self.graphql_headers = {
             f"Authorization": f"Bearer {self.datahub_token}",
             "X-DataHub-Actor": self.datahub_actor,
@@ -66,3 +85,4 @@ class RestClient(DatahubRestEmitter):
         self.dataset = datasets.Dataset(self)
         self.glossary_term = glossary_terms.GlossaryTerm(self)
         self.dashboard = dashboards.Dashboard(self)
+        self.data_job = data_jobs.DataJob(self)
